@@ -7,12 +7,13 @@ from pathlib import Path
 
 from .api import PlatformDirsABC
 
-if sys.platform.startswith("linux"):  # pragma: no branch # no op check, only to please the type checker
-    from os import getuid
-else:
+if sys.platform == "win32":
 
     def getuid() -> int:
-        raise RuntimeError("should only be used on Linux")
+        raise RuntimeError("should only be used on Unix")
+
+else:
+    from os import getuid
 
 
 class Unix(PlatformDirsABC):
@@ -136,6 +137,20 @@ class Unix(PlatformDirsABC):
         """
         return _get_user_media_dir("XDG_PICTURES_DIR", "~/Pictures")
 
+    @property
+    def user_videos_dir(self) -> str:
+        """
+        :return: videos directory tied to the user, e.g. ``~/Videos``
+        """
+        return _get_user_media_dir("XDG_VIDEOS_DIR", "~/Videos")
+
+    @property
+    def user_music_dir(self) -> str:
+        """
+        :return: music directory tied to the user, e.g. ``~/Music``
+        """
+        return _get_user_media_dir("XDG_MUSIC_DIR", "~/Music")
+
     @property
     def user_runtime_dir(self) -> str:
         """
