@@ -10,6 +10,7 @@ import pytest
 from _pytest.monkeypatch import MonkeyPatch
 from pytest_mock import MockerFixture
 
+from platformdirs import unix
 from platformdirs.unix import Unix
 
 
@@ -128,18 +129,16 @@ def test_xdg_variable_custom_value(monkeypatch: MonkeyPatch, dirs_instance: Unix
     assert result == "/tmp/custom-dir"
 
 
-def test_platform_non_linux(monkeypatch: MonkeyPatch) -> None:
-    from platformdirs import unix
-
+def test_platform_on_win32(monkeypatch: MonkeyPatch, mocker: MockerFixture) -> None:
+    monkeypatch.delenv("XDG_RUNTIME_DIR", raising=False)
+    mocker.patch("sys.platform", "win32")
+    prev_unix = unix
+    importlib.reload(unix)
     try:
-        with monkeypatch.context() as context:
-            context.setattr(sys, "platform", "magic")
-            monkeypatch.delenv("XDG_RUNTIME_DIR", raising=False)
-            importlib.reload(unix)
-        with pytest.raises(RuntimeError, match="should only be used on Linux"):
+        with pytest.raises(RuntimeError, match="should only be used on Unix"):
             unix.Unix().user_runtime_dir
     finally:
-        importlib.reload(unix)
+        sys.modules["platformdirs.unix"] = prev_unix
 
 
 def test_ensure_exists_creates_folder(mocker: MockerFixture, tmp_path: Path) -> None:
